pub struct DataField {
pub id: FieldId,
pub name: String,
pub logical_type: LogicalType,
}Expand description
Named field in a top-level table row or nested struct.
Fields
id: FieldIdname: Stringlogical_type: LogicalTypeImplementations
Sourceimpl DataField
impl DataField
Sourcepub fn new(
id: impl Into<FieldId>,
name: impl Into<String>,
logical_type: LogicalType,
) -> Result<Self>
pub fn new( id: impl Into<FieldId>, name: impl Into<String>, logical_type: LogicalType, ) -> Result<Self>
Construct a field with an explicit persisted id.
Prefer crate::TableSchemaBuilder for fresh schemas. This constructor
is intended for advanced uses such as restoration and interoperating
with a schema whose field identities are already known.