LogicalType

Struct LogicalType 

pub struct LogicalType {
    pub nullable: bool,
    pub kind: LogicalTypeKind,
}
Cross-language logical type, including nullability at every nesting level.

Fields

nullable: boolkind: LogicalTypeKind

Implementations

Source

impl LogicalType

pub fn boolean() -> Self

pub fn int8() -> Self

pub fn int16() -> Self

pub fn int32() -> Self

pub fn int64() -> Self

pub fn float32() -> Self

pub fn float64() -> Self

pub fn decimal(precision: u8, scale: u8) -> Self

pub fn date() -> Self

pub fn time(precision: u8) -> Self

pub fn timestamp(precision: u8, timestamp_kind: TimestampKind) -> Self

pub fn string() -> Self

pub fn binary() -> Self

pub fn list(element_type: LogicalType) -> Self

pub fn map(key_type: LogicalType, value_type: LogicalType) -> Self

pub fn struct_type(fields: Vec<DataField>) -> Self

pub fn struct_from_fields<I, N>(fields: I) -> Result<Self>
where I: IntoIterator<Item = (N, LogicalType)>, N: Into<String>,

Build a fresh struct type without requiring callers to assign field ids.

The assigned ids are local to this type and are renumbered again when the type is included in a crate::TableSchemaBuilder. Use Self::struct_type with explicit FieldId values only when restoring or constructing an already identified schema.

pub fn extension(extension: ExtensionType) -> Self

pub fn nullable(self) -> Self

pub fn not_null(self) -> Self