pub struct ReadOnlyTable { /* private fields */ }Expand description
Typed read-only access to one table in a fixed shard snapshot.
Implementations
Sourceimpl ReadOnlyTable
impl ReadOnlyTable
Sourcepub fn open(db: Arc<ReadOnlyDb>, name: impl Into<String>) -> Result<Self>
pub fn open(db: Arc<ReadOnlyDb>, name: impl Into<String>) -> Result<Self>
Open a table from metadata stored in this snapshot’s schema.
Sourcepub fn schema(&self) -> &TableSchema
pub fn schema(&self) -> &TableSchema
Return the persisted semantic schema of this table.
Sourcepub fn key_builder(&self) -> TableKeyBuilder
pub fn key_builder(&self) -> TableKeyBuilder
Start building one primary key in schema order.
Sourcepub fn project_by_names<S: AsRef<str>>(
&self,
field_names: &[S],
) -> Result<TableProjection>
pub fn project_by_names<S: AsRef<str>>( &self, field_names: &[S], ) -> Result<TableProjection>
Compile a reusable read projection from top-level field names.