pub struct TableProjection { /* private fields */ }Expand description
A reusable typed projection over one table or fixed snapshot table.
Implementations
Sourceimpl TableProjection
impl TableProjection
Sourcepub fn multi_get(&self, keys: &[TableKey]) -> Result<Vec<Option<Vec<Value>>>>
pub fn multi_get(&self, keys: &[TableKey]) -> Result<Vec<Option<Vec<Value>>>>
Read projected rows in input order, preserving duplicates and misses.
Sourcepub fn scan(&self, bucket: u16) -> Result<ProjectedTableScan>
pub fn scan(&self, bucket: u16) -> Result<ProjectedTableScan>
Scan projected rows in one bucket.
Sourcepub fn scan_bounds(
&self,
bucket: u16,
start_key_inclusive: Option<&TableKey>,
end_key_exclusive: Option<&TableKey>,
) -> Result<ProjectedTableScan>
pub fn scan_bounds( &self, bucket: u16, start_key_inclusive: Option<&TableKey>, end_key_exclusive: Option<&TableKey>, ) -> Result<ProjectedTableScan>
Scan projected rows over cached primary-key bounds.