pub struct TableScanSplitScannerBuilder { /* private fields */ }Expand description
Builder for one worker-local typed scan split scanner.
Implementations
Sourceimpl TableScanSplitScannerBuilder
impl TableScanSplitScannerBuilder
Sourcepub fn register_schema_transform<F, T>(
self,
transform_type: impl Into<String>,
factory: F,
) -> Result<Self>
pub fn register_schema_transform<F, T>( self, transform_type: impl Into<String>, factory: F, ) -> Result<Self>
Register a factory for persisted schema transform specifications before opening.
Sourcepub fn open(self) -> Result<TableScanSplitScanner>
pub fn open(self) -> Result<TableScanSplitScanner>
Open this fixed split using the supplied worker runtime configuration.