pub struct TableSchema {
pub fields: Vec<DataField>,
pub primary_key: Vec<FieldId>,
pub bucket_key: Vec<FieldId>,
}Expand description
User-visible semantic schema of a table.
Fields
fields: Vec<DataField>primary_key: Vec<FieldId>bucket_key: Vec<FieldId>Implementations
Sourceimpl TableSchema
impl TableSchema
Sourcepub fn builder() -> TableSchemaBuilder
pub fn builder() -> TableSchemaBuilder
Start building a fresh schema with deterministic generated field ids.
Sourcepub fn new(
fields: Vec<DataField>,
primary_key: Vec<FieldId>,
bucket_key: Vec<FieldId>,
) -> Result<Self>
pub fn new( fields: Vec<DataField>, primary_key: Vec<FieldId>, bucket_key: Vec<FieldId>, ) -> Result<Self>
Construct a schema with explicit field ids.
Prefer Self::builder for fresh schemas. This constructor preserves
ids exactly and is intended for restoration or advanced interoperability
with an already identified schema.